#!/usr/bin/env ruby
require("gsl")

N = 10000
rng = Rng.alloc
data = rng.exponential(2, N)
h = Histogram.alloc(100, [0, 15])
h.fill(data)

#result = h.fit_exponential
result = h.fit("exponential")
a = result[0]
b = result[1]

x = Vector.linspace(0, 15, 100)
y = a*Sf::exp(x*b)
graph(h, [x, y], "-C -g 3")

  
